@@ -78,112 +78,132 @@ class SaiDataset(Base):
     BODY_SEGMENTATION_MAPPING = {
         "default": 0,
         "background": 0,
+        # head
         "beard": 1,
-        "body": 2,
-        "brow": 3,
-        "cheek_left": 4,
-        "cheek_right": 5,
-        "chin": 6,
-        "clothing": 7,
-        "ear_left": 8,
-        "ear_right": 9,
-        "eye_left": 10,
-        "eye_right": 11,
-        "eyelashes": 12,
-        "eyelid": 13,
-        "eyes": 14,
-        "forehead": 15,
-        "glasses": 16,
-        "hair": 17,
-        "head": 18,
-        "headphones": 19,
-        "headwear": 20,
-        "jaw": 21,
-        "jowl": 22,
-        "lip_lower": 23,
-        "lip_upper": 24,
-        "mask": 25,
-        "mouth": 26,
-        "mouthbag": 27,
-        "mustache": 28,
-        "neck": 29,
-        "nose": 30,
-        "nose_outer": 31,
-        "nostrils": 32,
-        "shoulders": 33,
-        "smile_line": 34,
-        "teeth": 35,
-        "temples": 36,
-        "tongue": 37,
-        "undereye": 38,
-        "eyebrows": 89,
-        "torso_lower_left": 40,
-        "torso_lower_right": 41,
-        "torso_mid_left": 42,
-        "torso_mid_right": 43,
-        "torso_upper_left": 44,
-        "torso_upper_right": 45,
-        "arm_lower_left": 46,
-        "arm_lower_right": 47,
-        "arm_upper_left": 48,
-        "arm_upper_right": 49,
-        "hand_left": 50,
-        "hand_right": 51,
-        "finger1_mid_bottom_left": 52,
-        "finger1_mid_bottom_right": 53,
-        "finger1_mid_left": 54,
-        "finger1_mid_right": 55,
-        "finger1_mid_top_left": 56,
-        "finger1_mid_top_right": 57,
-        "finger2_mid_bottom_left": 58,
-        "finger2_mid_bottom_right": 59,
-        "finger2_mid_left": 60,
-        "finger2_mid_right": 61,
-        "finger2_mid_top_left": 62,
-        "finger2_mid_top_right": 63,
-        "finger3_mid_bottom_left": 64,
-        "finger3_mid_bottom_right": 65,
-        "finger3_mid_left": 66,
-        "finger3_mid_right": 67,
-        "finger3_mid_top_left": 68,
-        "finger3_mid_top_right": 69,
-        "finger4_mid_bottom_left": 70,
-        "finger4_mid_bottom_right": 71,
-        "finger4_mid_left": 72,
-        "finger4_mid_right": 73,
-        "finger4_mid_top_left": 74,
-        "finger4_mid_top_right": 75,
-        "finger5_mid_bottom_left": 76,
-        "finger5_mid_bottom_right": 77,
-        "finger5_mid_left": 78,
-        "finger5_mid_right": 79,
-        "finger5_mid_top_left": 80,
-        "finger5_mid_top_right": 81,
-        "nails_left": 82,
-        "nails_right": 83,
-        "leg_lower_left": 84,
-        "leg_lower_right": 85,
-        "leg_upper_left": 86,
-        "leg_upper_right": 87,
-        "foot_left": 88,
-        "foot_right": 89,
-        "pupil_left": 90,
-        "pupil_right": 91,
-        "eyelashes_left": 92,
-        "eyelashes_right": 93,
-        "eyelid_left": 92,
-        "eyelid_right": 93,
-        "eyebrow_left": 94,
-        "eyebrow_right": 95,
+        "brow": 2,
+        "cheek_left": 3,
+        "cheek_right": 4,
+        "chin": 5,
+        "ear_left": 6,
+        "ear_right": 7,
+        "forehead": 8,
+        "hair": 9,
+        "head": 10,
+        "jaw": 11,
+        "jowl": 12,
+        "lip_lower": 13,
+        "lip_upper": 14,
+        "mouth": 15,
+        "mouthbag": 16,
+        "mustache": 17,
+        "neck": 18,
+        "nose": 19,
+        "nose_outer": 20,
+        "nostrils": 21,
+        "orbit_left": 22,
+        "orbit_right": 23,
+        "smile_line": 24,
+        "teeth": 25,
+        "temples": 26,
+        "tongue": 27,
+        # eyes
+        "caruncle_left": 28,
+        "caruncle_right": 29,
+        "eyebrow_left": 30,
+        "eyebrow_right": 31,
+        "eyelashes_left": 32,
+        "eyelashes_right": 33,
+        "eye_fluid": 34,
+        "iris_left": 35,
+        "iris_right": 36,
+        "lower_eyelid_left": 37,
+        "lower_eyelid_right": 38,
+        "pupil_left": 39,
+        "pupil_right": 40,
+        "sclera_left": 41,
+        "sclera_right": 42,
+        "upper_eyelid_left": 43,
+        "upper_eyelid_right": 44,
+        # torso
+        "shoulders": 45,
+        "torso_lower_left": 46,
+        "torso_lower_right": 47,
+        "torso_mid_left": 48,
+        "torso_mid_right": 49,
+        "torso_upper_left": 50,
+        "torso_upper_right": 51,
+        # arms
+        "arm_lower_left": 52,
+        "arm_lower_right": 53,
+        "arm_upper_left": 54,
+        "arm_upper_right": 55,
+        # hands
+        "finger1_mid_bottom_left": 56,
+        "finger1_mid_bottom_right": 57,
+        "finger1_mid_left": 58,
+        "finger1_mid_right": 59,
+        "finger1_mid_top_left": 60,
+        "finger1_mid_top_right": 61,
+        "finger2_mid_bottom_left": 62,
+        "finger2_mid_bottom_right": 63,
+        "finger2_mid_left": 64,
+        "finger2_mid_right": 65,
+        "finger2_mid_top_left": 66,
+        "finger2_mid_top_right": 67,
+        "finger3_mid_bottom_left": 68,
+        "finger3_mid_bottom_right": 69,
+        "finger3_mid_left": 70,
+        "finger3_mid_right": 71,
+        "finger3_mid_top_left": 72,
+        "finger3_mid_top_right": 73,
+        "finger4_mid_bottom_left": 74,
+        "finger4_mid_bottom_right": 75,
+        "finger4_mid_left": 76,
+        "finger4_mid_right": 77,
+        "finger4_mid_top_left": 78,
+        "finger4_mid_top_right": 79,
+        "finger5_mid_bottom_left": 80,
+        "finger5_mid_bottom_right": 81,
+        "finger5_mid_left": 82,
+        "finger5_mid_right": 83,
+        "finger5_mid_top_left": 84,
+        "finger5_mid_top_right": 85,
+        "hand_left": 86,
+        "hand_right": 87,
+        "nails_left": 88,
+        "nails_right": 89,
+        # legs
+        "foot_left": 90,
+        "foot_right": 91,
+        "leg_lower_left": 92,
+        "leg_lower_right": 93,
+        "leg_upper_left": 94,
+        "leg_upper_right": 95,
+        # accessories
         "glasses_frame": 96,
         "glasses_lens_left": 97,
         "glasses_lens_right": 98,
-        "undereye_left": 99,
-        "undereye_right": 100,
-        "sclera_left": 101,
-        "sclera_right": 102,
-        "cornea_left": 103,
-        "cornea_right": 104,
+        "headphones": 99,
+        "headwear": 100,
+        "mask": 101,
+        # below are old classes that shouldn't exist anymore
+        # keeping these around to support older datasets
+        "body": 102,
+        "clothing": 103,
+        "cornea_left": 104,
+        "cornea_right": 105,
+        "eyebrows": 106,
+        "eyelashes": 107,
+        "eyelid": 108,
+        "eyes": 109,
+        "eyelid_left": 110,
+        "eyelid_right": 111,
+        "eye_left": 112,
+        "eye_right": 113,
+        "glasses": 114,
+        "undereye_left": 115,
+        "undereye_right": 116,
+        "undereye": 117,        
     }
     """
     Default body segmentation mapping.
@@ -205,8 +225,9 @@ class SaiDataset(Base):
         "skirt": 11,
         "scarf": 12,
         "vest": 13,
-        "hat": 14,
-        "shoe": 15,
+        "shoe": 14,
+        # this shouldn't exist anymore since it's now labeled as "headwear" in the body segmentation
+        "hat": 15,
     }
     """
     Default clothing segmentation mapping
@@ -222,6 +243,7 @@ class SaiDataset(Base):
         "eyelid_left",
         "eyelid_right",
         "eyes",
+        "forehead",
         "jaw",
         "jowl",
         "lip_lower",
@@ -486,12 +508,21 @@ class SaiDataset(Base):
     @property
     def body_segmentation_mapping(self) -> Dict[str, int]:
         """
-        Segment mapping for the dataset.
+        Body segmentation mapping for the dataset.
 
         :type: Dict[str, int]
         """
         return self._body_segmentation_mapping
 
+    @property
+    def clothing_segmentation_mapping(self) -> Dict[str, int]:
+        """
+        Clothing segmentation mapping for the dataset.
+
+        :type: Dict[str, int]
+        """
+        return self._clothing_segmentation_mapping
+
     @property
     def modalities(self) -> List[Modality]:
         """
