@@ -30,6 +30,8 @@ class _Extension(str, Enum):
     NORMALS = "normals.tif"
     DEPTH = "depth.tif"
     SEGMENTS = "segments.png"
+    CLOTHING_SEGMENTS = "clothing_segments.png"
+    UV = "UV.png"
     MEDIAPIPE_DENSE_OBJ = "mediapipe_dense.obj"
     SAI_DENSE_OBJ = "sai_dense.obj"
 
@@ -41,8 +43,9 @@ def _modality_files(modality: Modality) -> List[_Extension]:
         Modality.NORMALS: [_Extension.NORMALS],
         Modality.DEPTH: [_Extension.DEPTH],
         Modality.BODY_SEGMENTATION: [_Extension.INFO, _Extension.SEGMENTS],
-        Modality.CLOTHING_SEGMENTATION: None,
+        Modality.CLOTHING_SEGMENTATION: [_Extension.INFO, _Extension.CLOTHING_SEGMENTS],
         Modality.INSTANCE_SEGMENTATION: [_Extension.INFO, _Extension.SEGMENTS],
+        Modality.UV: [_Extension.UV],
         Modality.LANDMARKS_IBUG68: [_Extension.INFO],
         Modality.LANDMARKS_CONTOUR_IBUG68: [_Extension.INFO],
         Modality.LANDMARKS_KINECT_V2: [_Extension.INFO],
@@ -62,6 +65,8 @@ def _modality_files(modality: Modality) -> List[_Extension]:
         Modality.FACIAL_HAIR: [_Extension.INFO],
         Modality.EXPRESSION: [_Extension.INFO],
         Modality.GAZE: [_Extension.INFO],
+        Modality.GAZE_TARGET: [_Extension.INFO],
+        Modality.HEAD_TURN: [_Extension.INFO],
         Modality.FACE_BBOX: [_Extension.RGB, _Extension.INFO, _Extension.SEGMENTS],
         Modality.CAM_TO_HEAD: [_Extension.INFO],
         Modality.HEAD_TO_CAM: [_Extension.INFO],
@@ -174,12 +179,23 @@ class _ItemLoaderV1(_ItemLoader):
             segment_img, _ = self._read_body_segmentation(file_path, element_idx, info)
             return segment_img
 
+        if modality == Modality.CLOTHING_SEGMENTATION:
+            file_path = item_meta[
+                item_meta.EXTENSION == _Extension.CLOTHING_SEGMENTS
+            ].file_path.iloc[0]
+            clothing_segment_img, _ = self._read_clothing_segmentation(
+                file_path, element_idx, info
+            )
+            return clothing_segment_img
+
         if modality == Modality.INSTANCE_SEGMENTATION:
             file_path = item_meta[
                 item_meta.EXTENSION == _Extension.SEGMENTS
             ].file_path.iloc[0]
-            segment_img = self._read_instance_segmentation(file_path, element_idx, info)
-            return segment_img
+            segment_img, segment_mapping = self._read_instance_segmentation(
+                file_path, element_idx, info
+            )
+            return segment_img, segment_mapping
 
         if modality == Modality.NORMALS:
             normals_file = item_meta[
@@ -213,6 +229,17 @@ class _ItemLoaderV1(_ItemLoader):
                 raise ValueError(f"Error reading {depth_file}")
             return img
 
+        if modality == Modality.UV:
+            uv_file = item_meta[item_meta.EXTENSION == _Extension.UV].file_path.iloc[0]
+            uv_img = cv2.imread(uv_file, -1)
+            assert len(uv_img.shape) == 3
+            assert uv_img.shape[2] == 3
+            uv_img = cv2.cvtColor(uv_img, cv2.COLOR_BGR2RGB)
+            # first 2 channels correspond to UV coordinates
+            # third channel is meaningless, so ignore it
+            uv_img = uv_img[:, :, :2]
+            return uv_img
+
         if modality in (Modality.LANDMARKS_IBUG68, Modality.LANDMARKS_CONTOUR_IBUG68):
             return self._read_face_landmarks_2d(info, modality, element_idx)
 
@@ -254,7 +281,7 @@ class _ItemLoaderV1(_ItemLoader):
             }
 
             # v1 only has one character with ID 1
-            pupils = {1: pupils}
+            pupils = {"human_1": pupils}
             return pupils
 
         if modality == Modality.PUPILS_3D:
@@ -268,18 +295,18 @@ class _ItemLoaderV1(_ItemLoader):
             }
 
             # v1 only has one character with ID 1
-            pupils = {1: pupils}
+            pupils = {"human_1": pupils}
             return pupils
 
         if modality == Modality.IDENTITY:
             identity = info["identity_metadata"]["id"]
             # v1 only has one character with ID 1
-            identity = {1: identity}
+            identity = {"human_1": identity}
             return identity
 
         if modality == Modality.IDENTITY_METADATA:
             metadata = info["identity_metadata"]
-            metadata = {1: metadata}
+            metadata = {"human_1": metadata}
             return metadata
 
         if modality == Modality.HAIR:
@@ -289,7 +316,7 @@ class _ItemLoaderV1(_ItemLoader):
                 hair = None
 
             # v1 only has one character with ID 1
-            hair = {1: hair}
+            hair = {"human_1": hair}
             return hair
 
         if modality == Modality.FACIAL_HAIR:
@@ -299,14 +326,14 @@ class _ItemLoaderV1(_ItemLoader):
                 facial_hair = None
 
             # v1 only has one character with ID 1
-            facial_hair = {1: facial_hair}
+            facial_hair = {"human_1": facial_hair}
             return facial_hair
 
         if modality == Modality.EXPRESSION:
             expression = info["facial_attributes"]["expression"]
 
             # v1 only has one character with ID 1
-            expression = {1: expression}
+            expression = {"human_1": expression}
             return expression
 
         if modality == Modality.GAZE:
@@ -316,8 +343,22 @@ class _ItemLoaderV1(_ItemLoader):
             }
 
             # v1 only has one character with ID 1
-            gaze = {1: gaze}
+            gaze = {"human_1": gaze}
             return gaze
+        
+        if modality == Modality.GAZE_TARGET:
+            target = info["gaze_target"]["target_name"]
+
+            # v1 only has one character with ID 1
+            target = {"human_1": target}
+            return target
+
+        if modality == Modality.HEAD_TURN:
+            head_turn = info["facial_attributes"]["head_turn"]
+
+            # v1 only has one character with ID 1
+            head_turn = {"human_1": head_turn}
+            return head_turn
 
         if modality == Modality.FACE_BBOX:
             file_path = item_meta[
@@ -358,7 +399,7 @@ class _ItemLoaderV1(_ItemLoader):
             expanded_face_bbox = expand_bbox(face_bbox, self._face_bbox_pad)
 
             # v1 only has one character with ID 1
-            expanded_face_bbox = {1: expanded_face_bbox}
+            expanded_face_bbox = {"human_1": expanded_face_bbox}
 
             return expanded_face_bbox
 
@@ -379,7 +420,7 @@ class _ItemLoaderV1(_ItemLoader):
             )
 
             # v1 only has one character with ID 1
-            head2cam = {1: head2cam}
+            head2cam = {"human_1": head2cam}
             return head2cam
 
         if modality == Modality.CAM_TO_HEAD:
@@ -399,7 +440,7 @@ class _ItemLoaderV1(_ItemLoader):
             )
 
             # v1 only has one character with ID 1
-            head2world = {1: head2world}
+            head2world = {"human_1": head2world}
             return head2world
 
         if modality == Modality.WORLD_TO_HEAD:
@@ -512,6 +553,35 @@ class _ItemLoaderV1(_ItemLoader):
         segment_img = body_segmentation_mapping_int[img]
         return segment_img, body_segmentation_mapping_int
 
+    def _read_clothing_segmentation(
+        self, clothing_segmentation_file: str, element_idx: tuple, info: Dict[str, Any]
+    ) -> Tuple[np.ndarray, np.ndarray]:
+        img = cv2.imread(str(clothing_segmentation_file), cv2.IMREAD_UNCHANGED)
+        if img is None:
+            raise ValueError(f"Error reading {clothing_segmentation_file}")
+        if element_idx in self._image_sizes:
+            if self._image_sizes[element_idx] != img.shape[::-1]:
+                raise ValueError(
+                    f"Dimensions of different image modalities do not match."
+                )
+        else:
+            self._image_sizes[element_idx] = img.shape[::-1]
+
+        clothing_segmentation_mapping = info["clothing_segments_mapping"]
+        clothing_segmentation_mapping_int = np.full(
+            np.max(list(clothing_segmentation_mapping.values())) + 1,
+            self._clothing_segmentation_mapping["default"],
+            dtype=np.uint8,
+        )
+        for key, value in clothing_segmentation_mapping.items():
+            if key in self._clothing_segmentation_mapping:
+                clothing_segmentation_mapping_int[
+                    value
+                ] = self._clothing_segmentation_mapping[key]
+
+        segment_img = clothing_segmentation_mapping_int[img]
+        return segment_img, clothing_segmentation_mapping_int
+
     def _read_instance_segmentation(
         self, body_segmentation_file: str, element_idx: tuple, info: Dict[str, Any]
     ) -> np.ndarray:
@@ -535,7 +605,9 @@ class _ItemLoaderV1(_ItemLoader):
         instance_img[img == background_index] = 0
         instance_img[img != background_index] = 1
 
-        return instance_img
+        instance_mapping = {"human_1": 1}
+
+        return instance_img, instance_mapping
 
     def _read_rgb(self, rgb_file: str, element_idx: tuple) -> np.ndarray:
         img = cv2.imread(str(rgb_file), cv2.IMREAD_COLOR)
@@ -582,7 +654,7 @@ class _ItemLoaderV1(_ItemLoader):
             result[int(idd)] = (x * w, y * h)
 
         # v1 only has one character with ID 1
-        result = {1: result}
+        result = {"human_1": result}
 
         return result
 
@@ -614,7 +686,7 @@ class _ItemLoaderV1(_ItemLoader):
             landmarks = OutOfFrameLandmarkStrategy.clip_landmarks_(landmarks, h, w)
 
         # v1 only has one character with ID 1
-        landmarks = {1: landmarks}
+        landmarks = {"human_1": landmarks}
         return landmarks
 
     @classmethod
@@ -629,7 +701,7 @@ class _ItemLoaderV1(_ItemLoader):
             landmarks[int(lmk_name)] = tuple(landmark["camera_space_pos"])
 
         # v1 only has one character with ID 1
-        landmarks = {1: landmarks}
+        landmarks = {"human_1": landmarks}
         return landmarks
 
     def _read_obj(self, obj_file: str, world_to_cam: np.ndarray):
@@ -648,5 +720,5 @@ class _ItemLoaderV1(_ItemLoader):
         )
 
         # v1 only has one character with ID 1
-        result = {1: result}
+        result = {"human_1": result}
         return result
