@@ -38,8 +38,15 @@ def _modality_files(modality: Modality) -> List[_Extension]:
         Modality.NORMALS: [_Extension.NORMALS],
         Modality.DEPTH: [_Extension.DEPTH],
         Modality.BODY_SEGMENTATION: [_Extension.INFO, _Extension.BODY_SEGMENTATION],
-        Modality.CLOTHING_SEGMENTATION: [_Extension.INFO, _Extension.CLOTHING_SEGMENTATION],
-        Modality.INSTANCE_SEGMENTATION: [_Extension.INSTANCE_SEGMENTATION],
+        Modality.CLOTHING_SEGMENTATION: [
+            _Extension.INFO,
+            _Extension.CLOTHING_SEGMENTATION,
+        ],
+        Modality.INSTANCE_SEGMENTATION: [
+            _Extension.INFO,
+            _Extension.INSTANCE_SEGMENTATION,
+        ],
+        Modality.UV: None,
         Modality.LANDMARKS_IBUG68: [_Extension.INFO],
         Modality.LANDMARKS_CONTOUR_IBUG68: None,
         Modality.LANDMARKS_KINECT_V2: [_Extension.INFO],
@@ -59,6 +66,8 @@ def _modality_files(modality: Modality) -> List[_Extension]:
         Modality.FACIAL_HAIR: None,
         Modality.EXPRESSION: [_Extension.INFO],
         Modality.GAZE: [_Extension.INFO],
+        Modality.GAZE_TARGET: None,
+        Modality.HEAD_TURN: None,
         Modality.FACE_BBOX: [
             _Extension.INFO,
             _Extension.BODY_SEGMENTATION,
@@ -168,18 +177,24 @@ class _ItemLoaderV2(_ItemLoader):
             ].file_path.iloc[0]
             segment_img, _ = self._read_body_segmentation(file_path, element_idx, info)
             return segment_img
-        
+
         if modality == Modality.CLOTHING_SEGMENTATION:
-            file_path = item_meta[item_meta.EXTENSION == _Extension.CLOTHING_SEGMENTATION].file_path.iloc[0]
-            segment_img, _ = self._read_clothing_segmentation(file_path, element_idx, info)
+            file_path = item_meta[
+                item_meta.EXTENSION == _Extension.CLOTHING_SEGMENTATION
+            ].file_path.iloc[0]
+            segment_img, _ = self._read_clothing_segmentation(
+                file_path, element_idx, info
+            )
             return segment_img
 
         if modality == Modality.INSTANCE_SEGMENTATION:
             file_path = item_meta[
                 item_meta.EXTENSION == _Extension.INSTANCE_SEGMENTATION
             ].file_path.iloc[0]
-            segment_img = self._read_instance_segmentation(file_path, element_idx)
-            return segment_img
+            segment_img, mapping = self._read_instance_segmentation(
+                file_path, element_idx, info
+            )
+            return segment_img, mapping
 
         if modality == Modality.NORMALS:
             normals_file = item_meta[
@@ -200,6 +215,9 @@ class _ItemLoaderV2(_ItemLoader):
                 item_meta.EXTENSION == _Extension.DEPTH
             ].file_path.iloc[0]
             img = np.load(depth_file)["image"]
+            if img.ndim == 3:
+                assert img.shape[-1] == 1
+                img = np.squeeze(img, -1)
             if element_idx in self._image_sizes:
                 if self._image_sizes[element_idx] != img.shape[1::-1]:
                     raise ValueError(
@@ -357,17 +375,26 @@ class _ItemLoaderV2(_ItemLoader):
             instance_segmentation_file_path = item_meta[
                 item_meta.EXTENSION == _Extension.INSTANCE_SEGMENTATION
             ].file_path.iloc[0]
-            instance_segmentation = self._read_instance_segmentation(
-                instance_segmentation_file_path, element_idx
+            (
+                instance_segmentation,
+                instance_segmentation_mapping,
+            ) = self._read_instance_segmentation(
+                instance_segmentation_file_path, element_idx, info
             )
 
             face_bboxes = {}
 
             for human in info["humans"]:
                 instance_id = human["instance_id"]
+                # to handle really old jobs with integer IDs
+                if isinstance(instance_id, int):
+                    instance_id = str(instance_id)
                 human_face_mask = np.copy(face_mask)
                 # we only care about the face mask for this particular instance
-                human_face_mask[instance_segmentation != instance_id] = 0
+                human_face_mask[
+                    instance_segmentation
+                    != instance_segmentation_mapping.get(instance_id, 0)
+                ] = 0
                 face_bbox = get_bbox(human_face_mask)
                 expanded_face_bbox = expand_bbox(face_bbox, self._face_bbox_pad)
 
@@ -463,8 +490,11 @@ class _ItemLoaderV2(_ItemLoader):
                 ]
 
         body_segmentation = body_segmentation_mapping_int[img]
+        if body_segmentation.ndim == 3:
+            assert body_segmentation.shape[-1] == 1
+            body_segmentation = np.squeeze(body_segmentation, -1)
         return body_segmentation, body_segmentation_mapping_int
-    
+
     def _read_clothing_segmentation(
         self, clothing_segmentation_file: str, element_idx: tuple, info: Dict[str, Any]
     ) -> Tuple[np.ndarray, np.ndarray]:
@@ -485,15 +515,18 @@ class _ItemLoaderV2(_ItemLoader):
         )
         for key, value in clothing_segmentation_mapping.items():
             if key in self._clothing_segmentation_mapping:
-                clothing_segmentation_mapping_int[value] = self._clothing_segmentation_mapping[
-                    key
-                ]
+                clothing_segmentation_mapping_int[
+                    value
+                ] = self._clothing_segmentation_mapping[key]
 
         clothing_segmentation = clothing_segmentation_mapping_int[img]
+        if clothing_segmentation.ndim == 3:
+            assert clothing_segmentation.shape[-1] == 1
+            clothing_segmentation = np.squeeze(clothing_segmentation, -1)
         return clothing_segmentation, clothing_segmentation_mapping_int
 
     def _read_instance_segmentation(
-        self, instance_segmentation_file: str, element_idx: tuple
+        self, instance_segmentation_file: str, element_idx: tuple, info: dict
     ) -> np.ndarray:
         img = np.load(instance_segmentation_file)["segmentation"]
         if element_idx in self._image_sizes:
@@ -504,7 +537,16 @@ class _ItemLoaderV2(_ItemLoader):
         else:
             self._image_sizes[element_idx] = img.shape[1::-1]
 
-        return img
+        mapping = info["instance_segmentation_mapping"]
+        for human in info["humans"]:
+            human_instance_id = human["instance_id"]
+            if human_instance_id not in mapping:
+                mapping[human_instance_id] = -1
+
+        if img.ndim == 3:
+            assert img.shape[-1] == 1
+            img = np.squeeze(img, -1)
+        return img, mapping
 
     def _read_rgb(self, rgb_file: str, element_idx: tuple) -> np.ndarray:
         img = np.load(rgb_file)["image"]
@@ -517,7 +559,9 @@ class _ItemLoaderV2(_ItemLoader):
             raise ValueError(
                 f"Expected RGBA image to have 3 channels, got {img.shape[2]}"
             )
-
+        # this is a temporary fix to account for a bug in the scenarios API
+        if img.dtype == np.float16:
+            img = img.astype(np.uint8)
         return img
 
     @staticmethod
